#! /bin/sh
set -e

. /etc/default/devpts

[ `uname -s` = "Linux" ] || exit 0

make_devptmx()
{
    [ -c /dev/ptmx ] || mknod --mode=666 /dev/ptmx c 5 2
}

make_devpts()
{
    [ -d /dev/pts ] || mkdir --mode=755 /dev/pts
}

mount_devpts_fs()
{
    mount -t devpts devpts /dev/pts -ogid=${TTYGRP},mode=${TTYMODE}
}

devfs=$(grep -c '\<devfs' /proc/filesystems || true)
devpts=$(grep -c '\<devpts' /proc/filesystems || true)
devpts_mounted=$(mount | grep -c '^devpts' || true)

release=$(uname -r)
tail=${release#*.*.}
major_release=${release%.${tail}}
minor_release=${tail%%[-.]*}

if [ $devfs -eq 1 ]; then
    solution=devfs
elif [ $devpts -eq 1 ]; then
    solution=devpts
else
    solution=none
fi
case ${major_release} in
    2.[23456789] | 3.*)
	# Have 
	case $solution in
	    devfs|none)
		:
	    ;;
	    devpts)
		# devpts
		# create /dev/ptmx and /dev/pts dir.
		make_devptmx
		make_devpts
		# mount devpts fs on /dev/pts
		# maybe mountall.sh mounted it already, so check.
		if [ $devpts_mounted -lt 1 ]
		then
		    mount_devpts_fs
		fi
	    ;;
	esac
    ;;
    *)
    ;;
esac
